------------------------------------------------------------------------
-- Copyright Notice:                                                    
-- (c) Copyright 2004, National Optical Astronomy Observatory, which is 
-- operated for the National Science Foundation by the Association of   
-- Universities for Research in Astronomy under Cooperative Agreement   
-- No. AST-0132798.                                                     
--                                                                      
------------------------------------------------------------------------
-- PROJECT      :   MONSOON
-- BOARD        :   GENERIC
-- DEVICE ID    :   U22 (IR ACQ FPGA)
-- PARENT MODULE:   SEQUENCER TOP LEVEL (SEQ_FPGA)  
-- MODULE       :   Address(Program Counter) Stack 
-- VERSION      :   1.0 
------------------------------------------------------------------------
-- FILE NAME    :   Address_Stack.VHD
-- AUTHOR       :   KAVIRAJ CHOPRA
-- DATE         :   02/22/2003
-- COMPANY      :   NOAO
-- PLATFORM     :   Xilinx ISE 4.2
------------------------------------------------------------------------
-- DESCRIPTION  :   
-- The module is a simple 12 bit wide x 64 word deep RAM. Functions as a Program
-- Counnter Stack to facilitate the CALL and RET instruction implementation.
------------------------------------------------------------------------
-- IMPLEMENTATION NOTES :
-- The module will be implemented as a distributed RAM, 
-- The current depth of  the RAM is 16 words however it can be furhter
-- increased as and when needed.
------------------------------------------------------------------------
-- REVISION HISTORY :
-- DATE	    AUTHOR  VERSION  MODIFICATIONS
-- 03/11/03 KC      1.0
-- The stack depth is increased from 16 to 64.
------------------------------------------------------------------------
-- PORT DEFINITIONS 	:
-- AddrPtr : Memory Address 6 bits :- 64 words
-- AddrWriteData : Write port : 12 bit 
-- AddrWrite : Write Strobe
-- AddrRdData : Read Port : 12 bit
-- SysClk	: System Clock 40 MHz.
------------------------------------------------------------------------

library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity Address_Stack is
    Port ( AddrPtr : in std_logic_vector(5 downto 0);
           AddrWriteData : in std_logic_vector(11 downto 0);
           AddrWrite : in std_logic;
           AddrRdData : out std_logic_vector(11 downto 0);
		   SysClk	: in std_logic);
end Address_Stack;

architecture Behavioral of Address_Stack is
 type ram_type is array (63 downto 0) of std_logic_vector (11 downto 0); 
 signal RAM : ram_type; 

begin

 process (SysClk) 
 begin 
 	if rising_edge (SysClk) then  
 		if (AddrWrite = '1') then 
 			RAM(conv_integer(AddrPtr)) <= AddrWriteData; 
 		end if; 
 	end if; 
 end process;
 
 AddrRdData <= RAM(conv_integer(AddrPtr)); 

 end Behavioral;
