------------------------------------------------------------------------
-- Copyright Notice:                                                    
-- (c) Copyright 2004, National Optical Astronomy Observatory, which is 
-- operated for the National Science Foundation by the Association of   
-- Universities for Research in Astronomy under Cooperative Agreement   
-- No. AST-0132798.                                                     
--                                                                      
------------------------------------------------------------------------
-- PROJECT      :   MONSOON-TORRENT
-- BOARD        :   LOCAL CONTROL BOARD
-- DEVICE ID    :   VIRTEX 5LX
-- PARENT MODULE:   CFG_SERVICES
-- MODULE       :   PATTERN MEMORY CORE WRAPPER
-- VERSION      :   1.01
------------------------------------------------------------------------
-- FILE NAME    :   patmemcore_V101.vhd
-- AUTHOR       :   PETER MOORE
-- DATE         :   01/28/2010
-- COMPANY      :   NOAO
-- PLATFORM     :   Xilinx ISE 10.1.03
------------------------------------------------------------------------
-- DESCRIPTION  :   
-- Deocdes and executes the instruction based on the instruction 
-- definition as specified in the Instruction Set doccument. 
-- The Pattern Pointer which outputs the sequence pattern  
-- is controlled by execution of the data transfer instructions 
-- along with the Clock, Mode, Dev Addr and Board Sel registers.   
--
------------------------------------------------------------------------
-- IMPLEMENTATION NOTES :
-- Just wrappes the Xilinx generated IP to make a pretty schematic symbol.
------------------------------------------------------------------------
-- REVISION HISTORY :
-- DATE	      AUTHOR  VERSION  MODIFICATIONS
-- 01/26/2010   PCM     1.01      First used in version 1.01 of Configuration Services Module
--
------------------------------------------------------------------------

library ieee;
use ieee.std_logic_1164.ALL;
use ieee.numeric_std.ALL;
library UNISIM;
use UNISIM.Vcomponents.ALL;

entity PatternMemCore_Ver101 is
   port ( ADDRA : in    std_logic_vector (11 downto 0); 
          ADDRB : in    std_logic_vector (10 downto 0); 
          CLKA  : in    std_logic; 
          CLKB  : in    std_logic; 
          DINA  : in    std_logic_vector (15 downto 0); 
          WEA   : in    std_logic; 
          DOUTA : out   std_logic_vector (15 downto 0); 
          DOUTB : out   std_logic_vector (31 downto 0));
end PatternMemCore_Ver101;

architecture BEHAVIORAL of PatternMemCore_Ver101 is

component patmemcore
	port (
	clka     : IN std_logic;
	dina     : IN std_logic_VECTOR(15 downto 0);
	addra    : IN std_logic_VECTOR(11 downto 0);
	wea      : IN std_logic_VECTOR(0 downto 0);
	douta    : OUT std_logic_VECTOR(15 downto 0);
	clkb     : IN std_logic;
	dinb     : IN std_logic_VECTOR(31 downto 0);
	addrb    : IN std_logic_VECTOR(10 downto 0);
	web      : IN std_logic_VECTOR(0 downto 0);
	doutb    : OUT std_logic_VECTOR(31 downto 0));
end component;

   constant Disabled : std_logic_vector(0 downto 0) := (others => '0');
   constant NullData : std_logic_vector(31 downto 0) := (others => '0');
   signal   WrtStb   : std_logic_vector(0 downto 0);

begin

   WrtStb(0) <= WEA;    -- $^&%#@!  Hueviando Xilinx .. Porque tan ridiculo !!
   
   SeqPatternMemory: patmemcore
		port map (
			clka  => CLKA,
			dina  => DINA,
			addra => ADDRA,
			wea   => WrtStb,
			douta => DOUTA,
			clkb  => CLKB,
			dinb  => NullData,
			addrb => ADDRB,
			web   => Disabled,
			doutb => DOUTB
      );

end BEHAVIORAL;


